@@ -3,11 +3,6 @@
 Compatibility module
 """
 __author__ = 'Alisue <lambdalisue@hashnote.net>'
-try:
-    import configparser as ConfigParser
-except ImportError:
-    import ConfigParser
-
 try:
     # pip install keyring
     import keyring
@@ -21,12 +16,6 @@ except ImportError:
     filename = filename + ".keyring"
     keyring = PlaintextKeyring(filename)
 
-try:
-    from io import StringIO
-except ImportError:
-    # old python use StringIO
-    from StringIO import StringIO
-
 try:
     from email.header import Header
     from email.mime.text import MIMEText
